@@ -14,9 +14,11 @@ def run_from_config(
         args_s3,
         sql_credentials,
         amocrm_secrets,
+        is_oauth2=True
 ):
     """
     Read airflow task parameters (environment variables) to run sequence of tasks
+    :param is_oauth2:             ->type of authorization
     :param file_dir:              ->path to file to read
     :param etl_name_no_version:   ->etl_name_no_version to generate s3 path
     :param execution_date:        ->execution_date to generate s3 path
@@ -31,6 +33,7 @@ def run_from_config(
         "args_s3": args_s3,
         "execution_date": execution_date,
         "amocrm_secrets": amocrm_secrets,
+        "is_auth": is_oauth2
     }
 
     config_list = get_config_list(file_dir)
@@ -75,6 +78,7 @@ class AmocrmRunner:
             parser=None,
             api_version=4,
             batch_api=500,
+            is_oauth2=True
     ):
 
         self.entity = entity
@@ -95,6 +99,7 @@ class AmocrmRunner:
 
         self.api_version = api_version
         self.batch_api = batch_api
+        self.is_oauth2 = is_oauth2
         self.amocrm_secrets = amocrm_secrets
         self.amocrm_api_url = amocrm_api_url
 
@@ -186,6 +191,7 @@ class AmocrmRunner:
             args_api,
             date_modified_from=self.date_modified_from,
             batch_api=self.batch_api,
+            is_oauth2=self.is_oauth2
         )
         api_loader.extract()
 
